import locale

from fastapi import FastAPI
from fastapi.middleware.cors import CORSMiddleware
from fastapi.staticfiles import StaticFiles
from fastapi_cache import FastAPICache
from fastapi_cache.backends.inmemory import InMemoryBackend

from fabcal.routers import api_v1, frontend


app = FastAPI()

app.mount("/static", StaticFiles(directory="static"), name="static")

app.include_router(api_v1.router, prefix="/api/v1")
app.include_router(frontend.router, prefix="")

app.add_middleware(
    CORSMiddleware,
    allow_origins=[
        "https://fablab-altmuehlfranken.de",
        "https://www.fablab-altmuehlfranken.de",
    ],
)


locale.setlocale(locale.LC_TIME, locale.getlocale())


@app.on_event("startup")
async def startup():
    FastAPICache.init(InMemoryBackend())
